[SCM] WebKit Debian packaging branch, webkit-1.2, updated. upstream/1.1.90-6072-g9a69373

eric at webkit.org eric at webkit.org
Thu Apr 8 00:56:51 UTC 2010


The following commit has been merged in the webkit-1.2 branch:
commit f8a177c0d4a92b7d793cc2ac011d7108669d405a
Author: eric at webkit.org <eric at webkit.org@268f45cc-cd09-0410-ab3c-d52691b4dbfc>
Date:   Thu Jan 7 08:57:10 2010 +0000

    2010-01-07  Eric Seidel  <eric at webkit.org>
    
            Reviewed by Adam Barth.
    
            Add Chromium bots to the list of "core builders" (builders which stop the commit-queue when they turn red)
            https://bugs.webkit.org/show_bug.cgi?id=33290
    
            Add the Chromium builders to our list of core builders and test that our regexps work.
            I also updated our regexp testing to make sure we cover all known builders at build.webkit.org.
    
            * Scripts/webkitpy/buildbot.py:
            * Scripts/webkitpy/buildbot_unittest.py:
    
    git-svn-id: http://svn.webkit.org/repository/webkit/trunk@52908 268f45cc-cd09-0410-ab3c-d52691b4dbfc

diff --git a/WebKitTools/ChangeLog b/WebKitTools/ChangeLog
index c60c221..8f4921a 100644
--- a/WebKitTools/ChangeLog
+++ b/WebKitTools/ChangeLog
@@ -1,3 +1,16 @@
+2010-01-07  Eric Seidel  <eric at webkit.org>
+
+        Reviewed by Adam Barth.
+
+        Add Chromium bots to the list of "core builders" (builders which stop the commit-queue when they turn red)
+        https://bugs.webkit.org/show_bug.cgi?id=33290
+
+        Add the Chromium builders to our list of core builders and test that our regexps work.
+        I also updated our regexp testing to make sure we cover all known builders at build.webkit.org.
+
+        * Scripts/webkitpy/buildbot.py:
+        * Scripts/webkitpy/buildbot_unittest.py:
+
 2010-01-07  Adam Barth  <abarth at webkit.org>
 
         Reviewed by Eric Seidel.
diff --git a/WebKitTools/Scripts/webkitpy/buildbot_unittest.py b/WebKitTools/Scripts/webkitpy/buildbot_unittest.py
index a42ea85..bde3e04 100644
--- a/WebKitTools/Scripts/webkitpy/buildbot_unittest.py
+++ b/WebKitTools/Scripts/webkitpy/buildbot_unittest.py
@@ -110,18 +110,39 @@ class BuildBotTest(unittest.TestCase):
     def test_builder_name_regexps(self):
         buildbot = BuildBot()
 
+        # For complete testing, this list should match the list of builders at build.webkit.org:
         example_builders = [
-            { 'name': u'Leopard Debug (Build)', },
-            { 'name': u'Leopard Debug (Tests)', },
+            { 'name': u'Tiger Intel Release', },
+            { 'name': u'Leopard Intel Release (Build)', },
+            { 'name': u'Leopard Intel Release (Tests)', },
+            { 'name': u'Leopard Intel Debug (Build)', },
+            { 'name': u'Leopard Intel Debug (Tests)', },
+            { 'name': u'SnowLeopard Intel Release (Build)', },
+            { 'name': u'SnowLeopard Intel Release (Tests)', },
+            { 'name': u'SnowLeopard Intel Leaks', },
             { 'name': u'Windows Release (Build)', },
+            { 'name': u'Windows Release (Tests)', },
+            { 'name': u'Windows Debug (Build)', },
             { 'name': u'Windows Debug (Tests)', },
             { 'name': u'Qt Linux Release', },
+            { 'name': u'Gtk Linux Release', },
+            { 'name': u'Gtk Linux 32-bit Debug', },
+            { 'name': u'Gtk Linux 64-bit Debug', },
+            { 'name': u'Chromium Linux Release', },
+            { 'name': u'Chromium Mac Release', },
+            { 'name': u'Chromium Win Release', },
         ]
-        name_regexps = [ 'Leopard', "Windows.*Build" ]
+        name_regexps = [ "Leopard", "Windows.*Build", "Chromium" ]
         expected_builders = [
-            { 'name': u'Leopard Debug (Build)', },
-            { 'name': u'Leopard Debug (Tests)', },
+            { 'name': u'Leopard Intel Release (Build)', },
+            { 'name': u'Leopard Intel Release (Tests)', },
+            { 'name': u'Leopard Intel Debug (Build)', },
+            { 'name': u'Leopard Intel Debug (Tests)', },
             { 'name': u'Windows Release (Build)', },
+            { 'name': u'Windows Debug (Build)', },
+            { 'name': u'Chromium Linux Release', },
+            { 'name': u'Chromium Mac Release', },
+            { 'name': u'Chromium Win Release', },
         ]
 
         # This test should probably be updated if the default regexp list changes

diff --git a/WebKitTools/Scripts/webkitpy/buildbot.py b/WebKitTools/Scripts/webkitpy/buildbot.py
index b0eb0a4..e505fc8 100644
--- a/WebKitTools/Scripts/webkitpy/buildbot.py
+++ b/WebKitTools/Scripts/webkitpy/buildbot.py
@@ -44,9 +44,10 @@ class BuildBot:
         self.buildbot_host = host
         self.buildbot_server_url = "http://%s/" % self.buildbot_host
         
-        # If any of the Leopard build/test bots or the Windows builders are red we should not be landing patches.
-        # Other builders should be added to this list once they're known to be stable.
-        self.core_builder_names_regexps = [ 'Leopard', "Windows.*Build" ]
+        # If any Leopard builder/tester, Windows builder or Chromium builder is red we should not be landing patches.
+        # Other builders should be added to this list once they are known to be reliable.
+        # See https://bugs.webkit.org/show_bug.cgi?id=33296 and related bugs.
+        self.core_builder_names_regexps = [ "Leopard", "Windows.*Build", "Chromium" ]
 
     # If WebKit's buildbot has an XMLRPC interface we could use, we could do something more sophisticated here.
     # For now we just parse out the basics, enough to support basic questions like "is the tree green?"
-- 
WebKit Debian packaging



More information about the Pkg-webkit-commits mailing list